==> v0.3-beta.tar.gz: wonx/key.c <==
/*****************************************************************************/
/*                                                                   */
/*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>

#include "wonx_include/key.h"

#include "Wonx.h"

/*****************************************************************************/
/* ߴؿ                                                            */
/*****************************************************************************/

/*
 * XФȤƱȤʤʤʤɤ꤬ͤΤǡ
 * ߴؿ UNIXTimer_Pause(), UNIXTimer_Unpause() Ǥꡤ
 * ޳ߤߤƽԤޤunpause ޤˡ
 * ʤ餺 sync 褦ˤ롥
 */

/*
 * ޤΰߤΣŲ꤬ФƤΤǡ
 * ߴؿߴؿƤǤϤʤ
 * (ߤϥͥȤ뤬)
 * 褦ʽ򤹤ؿξϡɬ static ̴ؿ˽ޤȤᡤ
 * äƤӽФ褦ˤ뤳ȡ
 * ɽ⤢뤷͡
 */

int key_press_check(void)
{
  XDisplay x_display;
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_press_check() : "); fflush(stdout);

  x_display = WonxDisplay_GetXDisplay(Wonx_GetWonxDisplay());
  XDisplay_Sync(x_display);

  ret = XDisplay_GetKeyPress(x_display);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("return value = 0x%04x\n", (int)ret); fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

int key_hit_check(void)
{
  XDisplay x_display;
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_hit_check() : "); fflush(stdout);

  x_display = WonxDisplay_GetXDisplay(Wonx_GetWonxDisplay());
  XDisplay_Sync(x_display);

  ret = XDisplay_GetKeyPress(x_display);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("return value = 0x%04x\n", (int)ret); fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

int key_wait(void)
{
  XDisplay x_display;
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_wait() : "); fflush(stdout);

  x_display = WonxDisplay_GetXDisplay(Wonx_GetWonxDisplay());

  /*
   * ʲϥۥåȥݥåȤˤʤΤ!
   */

  ret = 0;
  do {
    XDisplay_Sync(x_display);
    ret = XDisplay_GetKeyPress(x_display);
  } while (ret == 0);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("return value = 0x%04x\n", (int)ret); fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

void key_set_repeat(int rate, int delay)
{
  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_set_repeat() : rate = %d, delay = %d, ", rate, delay);
  fflush(stdout);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("return value = none\n"); fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return;
}

int key_get_repeat(void)
{
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_get_repeat() : "); fflush(stdout);

  ret = 0;

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("return value = 0x%04x\n", (int)ret); fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

int key_hit_check_with_repeat(void)
{
  XDisplay x_display;
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_hit_check_with_repeat() : "); fflush(stdout);

  x_display = WonxDisplay_GetXDisplay(Wonx_GetWonxDisplay());
  XDisplay_Sync(x_display);

  ret = XDisplay_GetKeyPress(x_display);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("return value = 0x%04x\n", (int)ret); fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

/*****************************************************************************/
/* ޤ                                                                  */
/*****************************************************************************/

/*****************************************************************************/
/* End of File.                                                              */
/*****************************************************************************/

==> v0.5-beta.tar.gz: wonx/key.c <==
/*****************************************************************************/
/*                                                                   */
/*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>

#include "wonx_include/key.h"

#include "Wonx.h"

/*****************************************************************************/
/* ߴؿ                                                            */
/*****************************************************************************/

/*
 * XФȤƱȤʤʤʤɤ꤬ͤΤǡ
 * ߴؿ UNIXTimer_Pause(), UNIXTimer_Unpause() Ǥꡤ
 * ޳ߤߤƽԤޤunpause ޤˡ
 * ʤ餺 sync 褦ˤ롥
 */

/*
 * ޤΰߤΣŲ꤬ФƤΤǡ
 * ߴؿߴؿƤǤϤʤ
 * (ߤϥͥȤ뤬)
 * 褦ʽ򤹤ؿξϡɬ static ̴ؿ˽ޤȤᡤ
 * äƤӽФ褦ˤ뤳ȡ
 * ɽ⤢뤷͡
 */

int key_press_check(void)
{
  XDisplay x_display;
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_press_check() : "); fflush(stdout);

  x_display = WonxDisplay_GetXDisplay(Wonx_GetWonxDisplay());
  XDisplay_Sync(x_display);

  ret = XDisplay_GetKeyPress(x_display);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("call : key_press_check() : return value = 0x%04x\n", (int)ret);
  fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

int key_hit_check(void)
{
  XDisplay x_display;
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_hit_check() : "); fflush(stdout);

  x_display = WonxDisplay_GetXDisplay(Wonx_GetWonxDisplay());
  XDisplay_Sync(x_display);

  ret = XDisplay_GetKeyPress(x_display);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("call : key_hit_check() : return value = 0x%04x\n", (int)ret);
  fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

int key_wait(void)
{
  XDisplay x_display;
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_wait() : "); fflush(stdout);

  x_display = WonxDisplay_GetXDisplay(Wonx_GetWonxDisplay());

  /*
   * ʲϥۥåȥݥåȤˤʤΤ!
   */

  ret = 0;
  do {
    XDisplay_Sync(x_display);
    ret = XDisplay_GetKeyPress(x_display);
  } while (ret == 0);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("call : key_wait() : return value = 0x%04x\n", (int)ret);
  fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

void key_set_repeat(int rate, int delay)
{
  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_set_repeat() : rate = %d, delay = %d, ", rate, delay);
  fflush(stdout);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("call : key_set_repeat() : return value = none\n"); fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return;
}

int key_get_repeat(void)
{
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_get_repeat() : "); fflush(stdout);

  ret = 0;

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("call : key_get_repeat() : return value = 0x%04x\n", (int)ret);
  fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

int key_hit_check_with_repeat(void)
{
  XDisplay x_display;
  int ret;

  if (!Wonx_IsCreated()) Wonx_Create();

  /* ޤߤ */
  UNIXTimer_Pause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  printf("call : key_hit_check_with_repeat() : "); fflush(stdout);

  x_display = WonxDisplay_GetXDisplay(Wonx_GetWonxDisplay());
  XDisplay_Sync(x_display);

  ret = XDisplay_GetKeyPress(x_display);

  WonxDisplay_Sync(Wonx_GetWonxDisplay());

  printf("call : key_hit_check_with_repeat() : return value = 0x%04x\n",
	 (int)ret);
  fflush(stdout);

  /* ޤȤ᤹ */
  UNIXTimer_Unpause(WonxSystem_GetUNIXTimer(Wonx_GetWonxSystem()));

  return (ret);
}

/*****************************************************************************/
/* ޤ                                                                  */
/*****************************************************************************/

/*****************************************************************************/
/* End of File.                                                              */
/*****************************************************************************/
